@@ -3,7 +3,7 @@
  * Class representing a set of "Rule" timezone database entries of the
  * same name.
  *
- * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -116,17 +116,39 @@ class Horde_Timezone_Rule
             if (!isset($match[2])) {
                 $match[2] = 0;
             }
-            if ($rule[2] == $rule[3] && preg_match('/^\d+$/', $rule[6])) {
-                // Rule lasts only for a single year and starts on a specific
-                // date.
+            if (preg_match('/^\d+$/', $rule[6])) {
+                // Rule starts on a specific date.
                 $rdate = new Horde_Date(
                     array('year'  => $rule[2],
-                          'month' => Horde_Timezone::getMonth($rule[5]),
+                          'month' => $month,
                           'mday'  => $rule[6],
                           'hour'  => $match[1],
                           'min'   => $match[2],
-                          'sec'   => 0));
+                          'sec'   => 0)
+                );
                 $component->setAttribute('DTSTART', $rdate);
+                if ($rule[2] != $rule[3]) {
+                    // Rule lasts more than a single year.
+                    if ($rule[3][0] == 'm') {
+                        $until = '';
+                    } else {
+                        $last = new Horde_Date(
+                            array('year'  => $rule[3],
+                                  'month' => $month,
+                                  'mday'  => $rule[6],
+                                  'hour'  => $match[1],
+                                  'min'   => $match[2],
+                                  'sec'   => 0),
+                            $tzid);
+                        $last->setTimezone('UTC');
+                        $until = ';UNTIL=' . $last->format('Ymd\THis') . 'Z';
+                        $component->setAttribute(
+                            'RRULE',
+                            'FREQ=YEARLY;BYMONTH=' . $month
+                            . ';BYMONTHDAY=' . $rule[6]
+                            . $until);
+                    }
+                }
             } elseif (substr($rule[6], 0, 4) == 'last') {
                 // Rule starts on the last of a certain weekday of the month.
                 $weekday = $this->_weekdays[substr($rule[6], 4, 3)];
@@ -252,6 +274,8 @@ class Horde_Timezone_Rule
                     . ';BYMONTHDAY=' . implode(',', $days)
                     . ';BYDAY=-1' . Horde_String::upper(substr($weekday, 0, 2))
                     . $until);
+            } else {
+                continue;
             }
             $component->setAttribute('TZNAME', sprintf($name, $rule[9]));
             $tz->addComponent($component);
