@@ -34,4 +34,22 @@ class Horde_Timezone_IcalendarTest extends Horde_Test_Case
             $tz->getZone('Etc/UTC')->toVtimezone()->exportVcalendar()
         );
     }
+
+    public function testBug14221()
+    {
+        $tz = new Horde_Timezone_Mock('budapest');
+        $this->assertStringEqualsFile(
+            __DIR__ . '/fixtures/budapest.ics',
+            $tz->getZone('Europe/Budapest')->toVtimezone()->exportVcalendar()
+        );
+    }
+
+    public function testBug14162()
+    {
+        $tz = new Horde_Timezone_Mock('uruguay');
+        $this->assertStringEqualsFile(
+            __DIR__ . '/fixtures/uruguay.ics',
+            $tz->getZone('America/Montevideo')->toVtimezone()->exportVcalendar()
+        );
+    }
 }
